/**
  * INBOX25 Sales Sequence Drawer
  *
  * @class View.Views.Base.SalesSequenceView
  * @alias SUGAR.App.view.views.SalesSequenceView
  * @extends View.Views.Base.ListView
  */
({

  extendsFrom: 'ListView',
  inbox25_api_url: '',
  inbox25_api_params: '',
  inbox25_url: '',
  inbox25_url_ts: '',
  inbox25_system: '',
  modelList: [],
  moduleLabel: '',
  salesSequenceList: [],
  selectedSalesSequenceID: '',
  previewIframeSRC: '',
  className: 'sales-sequence-view',

  defaultLayoutEvents: {
    "salesSequence:save:fire": "fireSave",
  },

  initialize: function(view) {
    this.salesSequenceList = [];
    this.setupModelList(view.context.attributes.modelList);
    this._super('initialize', [view]);
    this.inbox25_url = SUGAR.App.user.attributes.inbox25_url;

    // Checks each Target List for the # of related records
    if(this.module == "ProspectLists") {
      var self = this;
      this.modelList.forEach(function (record) {
        app.api.records('read', self.module, {id: record.id}, {}, {
          context: self,
          success: function(record) {
            if(record.entry_count == 0) {
              app.alert.show('SalesSequenceAddingEmptyProspectListEmpty' + record.id, {
                level: 'error',
                messages: record.name + ' is an empty list',
                autoClose: false
              });
            }
          },
          error: function(error) {
            console.log(error);
          }
        });
      });
    }

    // Load a more recent timestamp to interact with the LeadFWD API
    var self = this;
    app.api.me('read', null, null, {
      success: function(data) {
        if (data && data.current_user && data.current_user.inbox25_url_ts) {
          self.inbox25_url_ts = data.current_user.inbox25_url_ts;
          self.inbox25_api_params = data.current_user.inbox25_api_params;
          self.inbox25_api_url = data.current_user.inbox25_api_url;
          self.loadSalesSequenceOptions();
        }
      },
      error: function(err) {
        app.error.handleHttpError(err);
      }
    });
  },

  _setLabels: function() {
    this._super('_setLabels');
    if(this.module == 'Accounts' || this.module == 'Opportunities') {
      this.modulePlural = app.lang.getAppListStrings('moduleList')['Contacts'];
      this.moduleSingular = app.lang.getAppListStrings('moduleListSingular')['Contacts'];
    }
    this.moduleLabel = this.moduleSingular;
    if(this.modelList.length > 1) {
      this.moduleLabel = this.modulePlural;
    }
  },

  setupModelList: function(inputList) {
    var recordList = [];
    inputList.forEach(function (model) {
      var record = model.attributes || model;

      // Status is derived from the email address
      var status = 'Missing Email Address';
      var status_color = 'red';
      var primary_email_address = null;
      if(record.email && record.email.length > 0) {
        record.email.forEach(function (emailAddress) {
          if(emailAddress.primary_address) {
            primary_email_address = emailAddress.email_address;
            if(emailAddress.invalid_email && emailAddress.opt_out) {
              status = 'Invalid Email Address and Opted-out';
            } else if(emailAddress.invalid_email) {
              status = 'Invalid Email Address';
            } else if(emailAddress.opt_out) {
              status = 'Opted-out';
            } else {
              status = 'Valid';
              status_color = 'green';
            }
          }
        });
      }

      // Builds the name with whatever fields are available and filled in, will
      // use the email address if no other name fields are found
      var name = '';
      if(record.salutation) name += record.salutation + ' ';
      if(record.first_name) name += record.first_name + ' ';
      if(record.last_name) name += record.last_name + ' ';
      if (name.length == 0) {
        name = record.name;
      }
      if (name.length == 0 && primary_email_address.length) {
        name = primary_email_address;
      }
      name = name.trim();

      if(record._module == 'ProspectLists') {
        status = null;
        status_color = null;
      }

      recordList.push({
        emailAddress: primary_email_address,
        id: record.id,
        name: name,
        title: record.title || '',
        status_color: status_color,
        status: status,
      });
    });

    this.modelList = recordList;
  },

  events: function() {
    var prototype = Object.getPrototypeOf(this);
    var parentEvents = _.result(prototype, 'events');
    return _.extend({}, parentEvents, {
      'change [data-action=select-sales-sequence]': 'selectSalesSequence',
      'click [data-action=remove-line]': 'handleSaveSalesSequenceRemoveLine'
    });
  },

  selectSalesSequence: function(event) {
    this.selectedSalesSequenceID = this.$(event.currentTarget).val();
    this.layout.$('[name="save_button"]').removeClass("disabled");
    this.loadPreviewPanel();
  },

  /**
   * Invoked when user clicks the "X" icon on a contact
   * @param {*} event
   */
  handleSaveSalesSequenceRemoveLine: function(event) {
    // Which record is it that we want to remove?
    var removeRecordID = event.target.dataset.id;

    // Removes desired record from storage list
    var recordList = [];
    _.each(this.modelList, function(v) {
      if(v.id != removeRecordID) {
        recordList.push(v);
      }
    });
    this.modelList = recordList;

    // Re-render the UI, which no longer includes the removed record
    this.render();
  },

  loadPreviewPanel: function () {
    if(!this.selectedSalesSequenceID) {
      return;
    }

    // Load a more recent timestamp to interact with the LeadFWD API
    var self = this;
    app.api.me('read', null, null, {
      success: function(data) {
        if (data && data.current_user && data.current_user.inbox25_url_ts) {
          self.inbox25_url_ts = data.current_user.inbox25_url_ts;
          self.inbox25_api_params = data.current_user.inbox25_api_params;
          self.inbox25_system = data.current_user.inbox25_system;

          var url = data.current_user.inbox25_url;
          url += '&seq=' + self.selectedSalesSequenceID;
          url += self.inbox25_url_ts;
          url += data.current_user.inbox25_mv;
          url += data.current_user.inbox25_suid;
          url += data.current_user.inbox25_system;

          var modelList = [];
          self.modelList.forEach(function (model) {
            if(model.status == 'Valid' || self.model.module == 'ProspectLists') {
              modelList.push({
                emailAddress: model.emailAddress,
                id: model.id,
                name: model.name,
              });
            }
          }, self);

          var postData = {
            module: self.module,
            recordList: modelList,
            salesSequenceID: self.selectedSalesSequenceID
          };

          var postDataString = JSON.stringify(postData);
          var frameSource = "<form id='tempId' action='" + url + "' method='post'>\n";
          frameSource += "<input type='hidden' name='json' value='" + postDataString + "' />\n";
          frameSource += "</form>\n";
          frameSource += "<script type='text/javascript'>\n";
          frameSource += "document.forms['tempId'].submit();\n";
          frameSource += "</script>";

          self.previewIframeSRC = frameSource;
          self.render();
        }
      },
      error: function(err) {
        app.error.handleHttpError(err);
      }
    });
  },

  loadSalesSequenceOptions: function () {

    // Leaving this intentionally, it is helpful for offline development
    // this.salesSequenceList.push({
    //   id: 'Fake List One',
    //   label: 'Fake List One'
    // });
    // this.salesSequenceList.push({
    //   id: 'Fake List Two',
    //   label: 'Fake List Two'
    // });
    // this.render();

    var url = this.inbox25_url + '&eq=1&suid=' + SUGAR.App.user.id + this.inbox25_url_ts + this.inbox25_system;
    self = this;
    $.ajax({
      method: 'GET',
      url: url,
    }).done(function(jsonData) {
      salesSequenceObjectList = $.parseJSON(jsonData);
      Object.entries(salesSequenceObjectList).map(salesSequenceObject => {
        self.salesSequenceList.push({
          id: salesSequenceObject[0],
          label: salesSequenceObject[1]
        });
      });
      self.render();
    });
  },

  fireSave: function() {

    var alertID = 'SalesSequenceSaving';
    app.alert.show(alertID, {
      level: 'process',
      title: 'Saving Sales Sequence...',
      autoClose: false
    });

    var recordIdList = [];
    this.modelList.forEach(function (model) {
      recordIdList.push(model.id);
    });
    var jsonRecordIdList = JSON.stringify(recordIdList);

    var dataString = this.inbox25_api_params;
    dataString += '&action_type=sequence';
    dataString += '&sugar_module=' + this.module;
    dataString += '&sequence_id=' + this.selectedSalesSequenceID;
    dataString += '&sugar_id=' + jsonRecordIdList;

    // Load a more recent timestamp to interact with the LeadFWD API
    var self = this;
    app.api.me('read', null, null, {
      success: function(data) {
        if (data && data.current_user && data.current_user.inbox25_url_ts) {
          self.inbox25_url_ts = data.current_user.inbox25_url_ts;
          self.inbox25_api_url = data.current_user.inbox25_api_url;

          var url = self.inbox25_api_url;
          dataString += self.inbox25_url_ts;
          dataString += data.current_user.inbox25_suid;
          dataString += data.current_user.inbox25_system;

          $.ajax({
            method: 'POST',
            url: url,
            data: dataString,
          }).done(function() {
            app.alert.show('SalesSequenceSaveSuccess', {
              level: 'success',
              messages: 'Sales Sequence Saved',
              autoClose: true
            });
          }).fail(function(response) {
            console.log(response);
            app.alert.show('SalesSequenceSaveFail', {
              level: 'error',
              messages: 'Sales Sequence could not be saved',
              autoClose: false,
            });
          }).always(function() {
            app.alert.dismiss(alertID);
            app.drawer.close();
          });
        }
      },
      error: function(err) {
        app.error.handleHttpError(err);
      }
    });



  }

});