(function(app){
    app.events.on('app:sync:complete', function(){

        showOnModuleList = [
            'Accounts',
            'Contacts',
            'Leads',
            'Opportunities',
            'ProspectLists',
            'Prospects'
        ];

        var openDrawerCallbackFromList = function(model){
            collection = app.controller.context.get('mass_collection');
            if(collection.models.length > 20 || collection.models.length < 1) {
                var msg = app.lang.get('TPL_MERGE_INVALID_NUMBER_RECORDS',
                    this.module,
                    {
                        minRecords: 1,
                        maxRecords: 20
                    }
                );
                app.alert.show('invalid-record-count', {
                    level: 'error',
                    messages: msg
                });
                return;
            }
            if(app.drawer.getActiveDrawerLayout() == app.controller.layout){
                app.drawer.open({
                    layout: 'salesSequence',
                    context: {
                        model: model,
                        modelList: collection.models
                    }
                }, function(){
                    app.controller.context.once('list:leadfwd-salesSequence:fire', openDrawerCallbackFromList);
                    app.controller.context.reloadData();
                });
            }
        };

        app.router.on('route:list', function(module){
            if(module && showOnModuleList.includes(module)) {
                app.controller.context.once('list:leadfwd-salesSequence:fire', openDrawerCallbackFromList);
            }
        });

        var openDrawerCallbackFromRecord = function(model, context, event, extraModelList){
            if(app.drawer.getActiveDrawerLayout() == app.controller.layout){
                var modelList = [];
                if(
                    (model.module == 'Accounts' || model.module == 'Opportunities')
                    && (!extraModelList)
                ) {

                    // If the call is coming from Opportunities it will be
                    // recast to Accounts, because we want to send all of the
                    // contacts from the Account, not just the few on the Opp.
                    var module = 'Accounts';
                    var id = model.get('account_id') || model.id;
                    app.api.relationships('read', module, {id: id, link: 'contacts'}, {view: 'subpanel-for-accounts', fields: 'title'}, {
                        success: function(result){
                            openDrawerCallbackFromRecord(model, null, null, result.records);
                        }
                    });
                    return;
                } else if(extraModelList && extraModelList.length == 0) {
                    if(model.module == 'Opportunities') {
                        var thisModuleLabel = app.lang.getAppListStrings('moduleListSingular')['Accounts'];
                        var thisRecordName = model.get('account_name');
                    } else {
                        var thisModuleLabel = app.lang.getAppListStrings('moduleListSingular')[model.module];
                        var thisRecordName = model.get('name');
                    }
                    contactLabel = app.lang.getAppListStrings('moduleListSingular')['Contacts'];
                    app.alert.show('invalid-record-count', {
                        level: 'error',
                        messages: 'The ' + thisModuleLabel + ' record <em>' + thisRecordName + '</em> has no ' + contactLabel + ' records to send to the Sales Sequence',
                    });
                    app.controller.context.once('button:leadfwd-salesSequence:fire', openDrawerCallbackFromRecord);
                    return;
                } else if(extraModelList && extraModelList.length > 0) {
                    extraModelList.forEach(function (model) {
                        modelList.push(model);
                    });
                } else {
                    modelList.push(model);
                }

                app.drawer.open({
                    layout: 'salesSequence',
                    context: {
                        model: model,
                        modelList: modelList,
                    }
                }, function(){
                    app.controller.context.once('button:leadfwd-salesSequence:fire', openDrawerCallbackFromRecord);
                    app.controller.context.reloadData();
                });
            }
        };

        app.router.on('route:record', function(module){
            if(module && showOnModuleList.includes(module)) {
                app.controller.context.once('button:leadfwd-salesSequence:fire', openDrawerCallbackFromRecord);
            }
        });

    });
})(SUGAR.App);