<?php
require_once('data/SugarBean.php');
class Iframeapp extends SugarBean {

  // corresponds with $manifest['version'] in manifest.php
  public static $module_version = '5.8.0PR8';

  var $name;
  var $date_entered;
  var $date_modified;
  var $modified_user_id;
  var $created_by;
  var $description;
  var $iframe_src;
  var $iframe_height;
  var $team_id;
  var $team_set_id;
  var $assigned_user_id;

  var $created_by_name;
  var $modified_by_name;
  var $assigned_user_name;

  var $module_dir = 'Iframeapp';
  var $table_name = "iframeapp";
  var $object_name = "Iframeapp";

  public function bean_implements($interface) {
    return ($interface == 'ACL');
  }

  public function get_summary_text() {
    return $this->module_dir;
  }

  public static function get_module_version() {
    return '&mv=' . self::$module_version;
  }

  public static function get_system_version() {
    if(
      isset($GLOBALS['suitecrm_version']) &&
      !empty($GLOBALS['suitecrm_version'])
    ) {
      return '&system=' . urlencode('SuiteCRM ' . $GLOBALS['suitecrm_version']);
    } else {
      return '&system=' . urlencode('SugarCRM ' . $GLOBALS['sugar_flavor'] . ' ' . $GLOBALS['sugar_version']);
    }
  }

  /**
   * Build the encrypted timestamp for the INBOX25 API calls
   * @return string
   */
  public static function get_url_ts() {

    // the API doesn't respond when the rfr is localhost, so always remap to
    // something functional
    $host = urlencode(parse_url($_SERVER['HTTP_REFERER'], PHP_URL_HOST));
    if($host == 'localhost') $host = 'inbox257.sugarondemand.com';

    $ts = '&ts=' . time() . '&rfr=' . $host;
    return $ts;
  }

  /**
   * Load current INBOX25 URL
   * @returns mixed string|null
   */
  public static function get_config_url() {
    global $sugar_config;
    return isset($sugar_config['inbox25']['url']) ? $sugar_config['inbox25']['url'] : NULL;
  }

  /**
   * Load current INBOX25 config iframe height
   * @returns mixed string
   */
  public static function get_config_height() {
    global $sugar_config;
    return isset($sugar_config['inbox25']['height']) ? $sugar_config['inbox25']['height'] : '800';
  }

  private static function getMainAccountLevel() {
    $iframe_src = self::get_config_url();
    $query = parse_url($iframe_src, PHP_URL_QUERY);
    parse_str($query, $queryPartList);
    return isset($queryPartList['ma']) ? $queryPartList['ma'] : NULL;
  }

  public static function enableProspectMenu() {
    $ma = self::getMainAccountLevel();
    $allowedValueList = array('0','1');
    return in_array($ma, $allowedValueList);
  }

  public static function enableSalesSequence() {
    $ma = self::getMainAccountLevel();
    $allowedValueList = array('0','1');
    return in_array($ma, $allowedValueList);
  }

  public static function enableBasicCampaignTypes() {
    $ma = self::getMainAccountLevel();
    $allowedValueList = array('0','1');
    return in_array($ma, $allowedValueList);
  }

  public static function enableAdvancedCampaignTypes() {
    $ma = self::getMainAccountLevel();
    $allowedValueList = array('1');
    return in_array($ma, $allowedValueList);
  }

  public static function enableLeadFwdMenuActions() {
    $ma = self::getMainAccountLevel();
    $allowedValueList = array('1');
    return in_array($ma, $allowedValueList);
  }

  public static function enableLogicHooks() {
    $ma = self::getMainAccountLevel();
    $allowedValueList = array('1');
    return in_array($ma, $allowedValueList);
  }

  /**
   * Use the known API URL and Timestamp to generate the appropriate API
   * receiver endpoint, which is always at `/listener.php`. Returns this URL
   * and any additional GET parameters appended to the URL.
   */
  public static function getListenerURL() {
    $iframe_src = Iframeapp::get_config_url();

    // parse_url($url,PHP_URL_PORT) will return nothing if no port is specified
    $port = parse_url($iframe_src, PHP_URL_PORT) ? ':' . parse_url($iframe_src, PHP_URL_PORT) : '';

    // build the URL with the optional $port
    $url = parse_url($iframe_src, PHP_URL_SCHEME)
    . '://'
    . parse_url($iframe_src, PHP_URL_HOST)
    . $port
    . '/listener.php';

    return array(
      $url,
      parse_url($iframe_src, PHP_URL_QUERY)
    );
  }

  public static function addSalesSequenceButtonToRecordButtons($viewdefs, $module) {

    // Ensures that current metadata includes button array and a dropdown button within it
    if(empty($viewdefs[$module]['base']['view']['record']['buttons'])) {
      $viewdefs[$module]['base']['view']['record']['buttons'] = array();
    }
    $currentButtonList = $viewdefs[$module]['base']['view']['record']['buttons'];

    $mainDropdownKey = null;
    foreach($currentButtonList as $k => $currentButton) {
      if(
          $currentButton['name'] == 'main_dropdown'
          && $currentButton['type'] == 'actiondropdown'
      ) {
          $mainDropdownKey = $k;
          break;
      }
    }

    if($mainDropdownKey === null) {
      $currentButtonList = array(
          'type' => 'actiondropdown',
          'name' => 'main_dropdown',
          'primary' => true,
          'showOn' => 'view',
          'buttons' => array(),
      );
      $mainDropdownKey = 0;
    }

    // Adds our custom button to the existing action menu
    $currentButtonList[$mainDropdownKey]['buttons'][] = array(
      'type' => 'divider',
    );
    $currentButtonList[$mainDropdownKey]['buttons'][] = array(
      'type' => 'rowaction',
      'event' => 'button:leadfwd-salesSequence:fire',
      'label' => 'Add to Sequence',
      'acl_action' => 'edit',
    );

    $viewdefs[$module]['base']['view']['record']['buttons'] = $currentButtonList;
    return $viewdefs;
  }

  public function smartyAddActionButton($event, $args) {
    $this->smartyAddActionButtonRecordView($event, $args);
    $this->smartyAddActionButtonListView($event, $args);
  }

  public function smartyAddActionButtonRecordView($event, $args) {
    echo <<<EOJS
<script type='text/javascript' src='modules/Iframeapp/smartySalesSequenceHelper.js'></script>
<script type='text/javascript'>
    ///////////////////////////////////////////////////////////////////////////
    // Adds our custom button to the existing Actions list
    ///////////////////////////////////////////////////////////////////////////

    // works on SuiteCRM UI
    $('#tab-actions .dropdown-menu').append(
      '<li><input id="addToSalesSequence" title="Add to Sequence" class="button" onclick="openSalesSequenceModalFromRecordView(this);return false" type="button" value="Add to Sequence"></li>'
    );
    $('.detail-view').ready(function() {
      $('.detail-view').append(salesSequenceDialog);

      // Use the absence of the modal plugin to identify SugarCRM 6.5 CE, which
      // needs helpers to create a modal dialog
      if(!$ || !$.fn || !$.fn.modal) {
          $('#sales-sequence-close-btn').on("click", function() {
              var dialog = $('#salesSequenceDialog');
              modalToggleHelper(dialog);
          });
      }
    });

    // works on Sugar 6.5 UI
    $('#detail_header_action_menu li ul').append(
        '<li><input id="addToSalesSequence" title="Add to Sequence" class="button" onclick="openSalesSequenceModalFromRecordView(this);return false" type="button" value="Add to Sequence"></li>'
    );
    $('.content').ready(function() {
      $('.content').append(salesSequenceDialog);

      // Use the absence of the modal plugin to identify SugarCRM 6.5 CE, which
      // needs helpers to create a modal dialog
      if(!$ || !$.fn || !$.fn.modal) {
          $('#sales-sequence-close-btn').on("click", function() {
              var dialog = $('#salesSequenceDialog');
              modalToggleHelper(dialog);
          });
      }
    });
</script>
EOJS;
    $this->smartyAddActionButtenLegacyHelper();
  }

  public function smartyAddActionButtonListView($event, $args) {
    echo <<<EOJS

<script type='text/javascript' src='modules/Iframeapp/smartySalesSequenceHelper.js'></script>
<script type='text/javascript'>

    ///////////////////////////////////////////////////////////////////////////
    // Adds our custom button to the existing Actions list
    ///////////////////////////////////////////////////////////////////////////
    $('.selectActions .subnav').append(
        '<li><a href="javascript:void(0);" onclick="openSalesSequenceModalFromListView(this);return false;">Add to Sequence</a></li>'
    );

    $('.listViewBody').ready(function() {
        $('.listViewBody').append(salesSequenceDialog);

        // Use the absence of the modal plugin to identify SugarCRM 6.5 CE, which
        // needs helpers to create a modal dialog
        if(!$ || !$.fn || !$.fn.modal) {
            $('#sales-sequence-close-btn').on("click", function() {
                var dialog = $('#salesSequenceDialog');
                modalToggleHelper(dialog);
            });
        }
    });
</script>
EOJS;
    $this->smartyAddActionButtenLegacyHelper();
  }

  public function smartyAddActionButtenLegacyHelper() {

    // SugarCRM 6.5 and early versions of SuiteCRM do not yet have the suitep
    // icon class, so we need to detect this and handle it
    $suiteMinorVersion = 0;
    if(!empty($GLOBALS['sugar_config']['suitecrm_version'])) {
      $suiteMinorVersion = (int)explode('.', $GLOBALS['sugar_config']['suitecrm_version'])[1];
    }

    if($suiteMinorVersion <= 9) {
      echo <<<EOHACK
      <style type='text/css'>
      .suitepicon-action-view-project-tasks:before {
        content: url("themes/default/images/green_camp.gif");
      }
      .modal-preload-hidden {
        min-height: 100px;
        background-image: url("themes/default/images/img_loading_54.gif");
        background-position: center;
        background-repeat: no-repeat;
      }
      </style>
EOHACK;
    }

    // SugarCRM 6.5 does not include the requisite Bootstrap Modal
    // functionality that SuiteCRM includes, which throws off the
    // styling and .modal functionality. Here we attempt to recreate
    // it in as few hacks as possible
    if(empty($GLOBALS['sugar_config']['suitecrm_version'])) {
      echo <<<EOHACK
      <style type='text/css'>
        .hidden {
          display:none;
        }
        .modal-header button {
          float: right;
          background: 0 0;
          border: 0;
          font-size: 2em;
        }
        .modal-header {
          padding-bottom: 20px;
          border-bottom: 1px solid black;
        }
        .modal-header button:hover {
          color: black;
        }
        #salesSequenceDialog {
          display: none;
        }
        #salesSequenceDialog.in {
          display: block;
        }
        #salesSequenceContentWrapper {
          padding: 0 10px;
        }
        #salesSequenceDialog.in .modal-dialog {
          background-color: #fff;
          background-clip: padding-box;
          border: 1px solid rgba(0,0,0,.2);
          border-radius: 6px;
        }
        #sales-sequence-record-list li {
          list-style-type: disc;
        }
        .salesSequenceLeft {
          float: left;
          width: 50%;
        }
        .salesSequenceRight {
          float: right;
          width: 50%;
        }
      </style>
EOHACK;
    }
  }

}
