<?php
require_once('modules/Administration/QuickRepairAndRebuild.php');
require_once('modules/Configurator/Configurator.php');
require_once('modules/ModuleBuilder/parsers/ParserFactory.php');

function post_install() {
  global $db, $sugar_config;

  // If not already set, set the base URL for the iframe URLs. This can be
  // manually changed to a LeadFWD dev. instance if needed.
  if(empty($sugar_config['inbox25']) || empty($sugar_config['inbox25']['iframe_base'])) {
    $configurator = new Configurator();
    $configurator->loadConfig();
    $configurator->config['inbox25']['iframe_base'] = 'https://app.inbox25.com/inbox25_module.php';
    $configurator->saveConfig();
  }

  // copy existing config. to new config. structure if we haven't already set
  // the connection info
  if(empty($sugar_config['inbox25']) || empty($sugar_config['inbox25']['url'])) {
    $result = $db->query('select iframe_src, iframe_height from iframeapp where deleted=0 order by date_modified desc limit 1');
    while($row = $db->fetchByAssoc($result)) {
      $url = $row['iframe_src'];
      $height = $row['iframe_height'];
      $configurator = new Configurator();
      $configurator->loadConfig();
      $configurator->config['inbox25']['url'] = $url;
      $configurator->config['inbox25']['height'] = $height;
      $configurator->saveConfig();
      echo "LeadFWD Config: updating config. backend with found iframe URL {$url} <br />" . PHP_EOL;
      echo "LeadFWD Config: updating config. backend with found iframe height {$height} <br />" . PHP_EOL;
    }
  }

  // Add the footerTpl information to the detail view metadata for all
  // supported modules
  // https://community.sugarcrm.com/thread/18554
  $footerTpl = 'modules/Iframeapp/OtherModuleTpls/DetailView.tpl';
  $modules_to_support = array(
    'Accounts',
    'Contacts',
    'Leads',
    'Opportunities',
    'Prospects',
  );
  foreach($modules_to_support as $module) {

    try {
      $view_array = ParserFactory::getParser('detailview', $module);
      // see if there is an existing value
      if(!empty($view_array->_viewdefs['templateMeta']['form']['footerTpl'])) {
        $existing_value = $view_array->_viewdefs['templateMeta']['form']['footerTpl'];
        if($existing_value != $footerTpl) {
          echo "<span style='color:red;font-weight:bold;'>LeadFWD Problem: {$module} module already has a footerTpl specified. This installer will not override it, which means the LeadFWD record-view integration will not function for this module until this is resolved.</span><br />" . PHP_EOL;
        }
      }
      else {
        $view_array->_viewdefs['templateMeta']['form']['footerTpl'] = $footerTpl;
        $view_array->handleSave(false);
      }
    } catch (\Exception $e) {
      echo "Skipping metadata update for {$module}, it does not have legacy metadata to update <br />" . PHP_EOL;
    }

  }

  // run a full Quick Repair and Rebuild
  $repair = new RepairAndClear();
  $repair->repairAndClearAll(array('clearAll'), array('All Modules'), TRUE, FALSE);

  // prompt user to config. the LeadFWD connection info.
  global $sugar_config;
  $url = $sugar_config['site_url'] . '/index.php?module=Administration&action=Inbox25';
  $onclick = "window.open('{$url}','popup','width=600,height=600'); return false;";

  $system = 'SugarCRM';
  if(isset($GLOBALS['suitecrm_version']) && !empty($GLOBALS['suitecrm_version'])) $system = 'SuiteCRM';

  echo "<br />" . PHP_EOL;
  echo "<h2>Thanks for installing the LeadFWD {$system} Plugin</h2>" . PHP_EOL;
  echo "<p>Please configure your LeadFWD connection "
  . "<a href=\"{$url}\" onclick=\"{$onclick}\">on the admin. config. page</a>"
  . "</p>";

}
